@@ -36,6 +36,26 @@ lapply(
         )
       }
     )
+    testthat::test_that(
+      paste(text, "IndirectCentrals"),
+      {
+        testthat::expect_true(
+          all(
+            (
+              answer - c(
+                as.vector(
+                  cTMed:::.IndirectCentrals(
+                    phi = phi,
+                    delta_t = delta_t
+                  )
+                ),
+                delta_t
+              )
+            ) <= tol
+          )
+        )
+      }
+    )
     indirect_central <- IndirectCentral(
       phi = phi,
       delta_t = 1:5
